summaryrefslogtreecommitdiff
path: root/cmake
diff options
context:
space:
mode:
authorDaniel Dunbar <daniel@zuster.org>2009-11-25 04:46:58 +0000
committerDaniel Dunbar <daniel@zuster.org>2009-11-25 04:46:58 +0000
commitf87ea4dd9ac9816131ee52ee6393c7b4012f2e68 (patch)
tree26716b9aac7cd72088d592c94353fff0da1a0664 /cmake
parent4fc760ecb9b5738111b00c5b798188c721a1e269 (diff)
downloadllvm-f87ea4dd9ac9816131ee52ee6393c7b4012f2e68.tar.gz
llvm-f87ea4dd9ac9816131ee52ee6393c7b4012f2e68.tar.bz2
llvm-f87ea4dd9ac9816131ee52ee6393c7b4012f2e68.tar.xz
Add the rest of the build system logic for optional target disassemblers
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@89841 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'cmake')
-rwxr-xr-xcmake/modules/LLVMConfig.cmake6
1 files changed, 5 insertions, 1 deletions
diff --git a/cmake/modules/LLVMConfig.cmake b/cmake/modules/LLVMConfig.cmake
index a7536748a3..0744b50d64 100755
--- a/cmake/modules/LLVMConfig.cmake
+++ b/cmake/modules/LLVMConfig.cmake
@@ -32,7 +32,7 @@ endfunction(explicit_llvm_config)
function(explicit_map_components_to_libraries out_libs)
set( link_components ${ARGN} )
foreach(c ${link_components})
# add codegen, asmprinter, asmparser
list(FIND LLVM_TARGETS_TO_BUILD ${c} idx)
if( NOT idx LESS 0 )
list(FIND llvm_libs "LLVM${c}CodeGen" idx)
@@ -58,6 +58,10 @@ function(explicit_map_components_to_libraries out_libs)
if( NOT asmidx LESS 0 )
list(APPEND expanded_components "LLVM${c}Info")
endif()
+ list(FIND llvm_libs "LLVM${c}Disassembler" asmidx)
+ if( NOT asmidx LESS 0 )
+ list(APPEND expanded_components "LLVM${c}Disassembler")
+ endif()
elseif( c STREQUAL "native" )
list(APPEND expanded_components "LLVM${LLVM_NATIVE_ARCH}CodeGen")
elseif( c STREQUAL "nativecodegen" )
@@ -32,7 +32,7 @@ endfunction(explicit_llvm_config)
set( link_components ${ARGN} )
foreach(c ${link_components})
- # add codegen, asmprinter, asmparser
+ # add codegen, asmprinter, asmparser, disassembler
list(FIND LLVM_TARGETS_TO_BUILD ${c} idx)
if( NOT idx LESS 0 )